@@ -20,7 +20,7 @@ no if $] > 5.017010, warnings => 'experimental::smartmatch';
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.27_11';
+our $VERSION = '0.27_13';
 use English qw( -no_match_vars );    # Avoids reg-ex performance penalty
 local $OUTPUT_AUTOFLUSH = 1;
 
@@ -402,11 +402,11 @@ sub _find_makefile_test_requires {
 	$self->xtests_use_ok();
 
 	# do extra test early to identify eval befroe hand
-	$self->xtests_eval();
+	$self->xtests_eval('test_requires');
 
 	# do extra test early check for use_module before hand
 #	p $filename;
-	$self->xtests_use_module();
+	$self->xtests_use_module('test_requires');
 
 	my $prereqs = $self->scanner->scan_ppi_document($self->ppi_document);
 	my @modules = $prereqs->required_modules;
@@ -941,7 +941,7 @@ App::Midgen - Check B<requires> & B<test_requires> of your package for CPAN incl
 
 =head1 VERSION
 
-This document describes App::Midgen version: 0.27_11
+This document describes App::Midgen version: 0.27_13
 
 =head1 SYNOPSIS
 
